package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut

__DATA__

M35J0``,````$````__\``+@`````````0```````````````````````````
M````````````````````^`````X?N@X`M`G-(;@!3,TA5&AI<R!P<F]G<F%M
M(&-A;FYO="!B92!R=6X@:6X@1$]3(&UO9&4N#0T*)``````````-)82,243J
MWTE$ZM])1.K?RECDWTM$ZM\F6^#?0D3JWR9;[M]+1.K?RDRWWTU$ZM\R6.;?
M2T3JWTE$Z]\;1.K?MF3NWTI$ZM]_8N#?2T3JW_%"[-](1.K?4FEC:$E$ZM\`
M``````````````````````````````!010``3`$$`(ZK:T<``````````.``
M#P$+`08``#````"@````````(#H````0````0`````!````0````$```!```
M```````$``````````#@````$```Q#X!``,``````!```!``````$```$```
M`````!```````````````.R=``!D`````,```-`1````````````````````
M```````````````P00``'```````````````````````````````````````
M````````````````````0```+`$`````````````````````````````````
M`"YT97AT````7"L````0````,````!```````````````````"```&`N<F1A
M=&$``/!C````0````'````!```````````````````!```!`+F1A=&$```!D
M!````+`````0````L```````````````````0```P"YR<W)C````T!$```#`
M````(````,```````````````````$```,``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%:^B$%``%9H(#E``&AL04``Z`0I``!0Z/@H``"#Q!!6:`XY0`!H5$%``.CK
M*```4.C?*```@\007L-5B^R![`@$``!35E=HL$%``.BH`0``B47\C87X^___
MQP0D``0``#/;4%/_%1!`0`"%P`^%3`$``/\U$+!``(MU"%;_%81`0`!9687`
M5G03:*!!0`#H\P$``%F+QEGI5P$``.@U*0``_S44L$``BSV,0$``B47X_W4,
M_]>#Q`R+\#OS#X0?`0``.!YU!;Z<04``.5W\=!-6_W7\Z/<H``!9A<!9#X3+
M````5NCM*```BE0P_UF+#1"P0``Z$74*2(@<!HI4!O_K[(M5^/]U"(U$$`$]
M``0```^-S0```%%6C87X^___:)1!0`!0_Q640$``Z.HG``!0Z/8G``"+,.C=
M)P``4.CC)P``@\0<4(V%^/O__U#HQR<``%#HTR<``%G_,/]64(/$#(7`=4CH
MKR<``%#HM2<``&:+0`999B4`\&8]`(!U+NB5)P``4.BA)P``BS!9C87X^___
M:@%0Z'XG``!0Z(HG``!9_S#_%H/$#(7`=!#_-12P0`!3_]=96>GZ_O__C87X
M^___4&B@04``Z+<```"-A?C[__]0_Q5$0$``@\0,ZQ+_=0AHH$%``.B8````
MBT4(65E?7EO)PU6+[(U%"%#_=0CH!````%E97<-5B^Q14U:+=0A7A?9T9HL=
M@$!``/_3@S@`=%F*#HO&A,ET"X#Y/70&BD@!0.OQ*\:)1?S_TXLPBSZ%_W0W
M_W7\_W4(5_\50$!``(/$#(7`=0F+1?R`/`<]=`6#Q@3KV/_3*S"+10S!_@*)
M,(M%_(U$!P'K`C/`7UY;R<-5B^Q148M%#(`X/74#_T4,4U97_W4,Z#4G``"+
M70B)1?B-1?Q04^A:____BS6`0$``B_B#Q`R%_W0B5^@0)P``.T7X60^"RP``
M`(M-#(H!B`='083`=?;I/`$``/_6BP`S_S/).0AT!H/`!$?K]CD-1+1``'1`
MZ!DF``!0Z"LF``"+&%F-!+T(````4/_6_S#H_R4``%#H$28``%G_,/]3!(/$
M#(O8_]:)&/_6@S@`=57IL0```,<%1+1```$```#HSR4``%#HX24``(L868T$
MO0@```!0Z+DE``!0Z,LE``!9_S#_$XO8687;671YB\?!X`)0_];_,%/_%7Q`
M0`"#Q`S_UHD8_]:+`(M="(-DN`0`B7W\B@.+^X3`=`H\/70&BD<!1^ORZ&@E
M``!0Z'HE``"+$(M%^"O[68E5"(U$!P)0Z$TE``!0Z%\E``!9_S"+10C_$%F+
M^%G_UHL`BTW\A?^)/(AU!8/(_^LN_]:+`(M-_(L$B(H+0X3)B`AT"(#Y/70#
M0.OOBU4,Q@`]0(H*B`A`0H3)=?8SP%]>6\G#BT0D!%:+\(O(B@"$P'07BQ40
ML$``BA(ZPG4#C7$!BD$!083`=?&+QE[#5HMT)`B%]G1O@#X`=&I6Z',E``"-
M1##_68L-$+!``#O&=A:*$3@0=05(.\9W]SO&=@DX$'0#2.OU.\9U"8H`.@%T
M-5'K-T@[QG8&BA`Z$73U*\:-2`*!^0`$``!V!#/`7L-`4%:^/+!``%;_%7A`
M0`"#Q`R+QE[#:)Q!0`#_%41`0`!97L-5B^R#["135E=J"%F^A$)``(U]W&AT
M0D``\Z5FI>@)`0``QP0D:$)``.C]````N[!!0`!3Z/(```"^7$)``%;HYP``
M`+]00D``5^C<````:$1"0`#HT@```&B@04``Z,@```!H.$)``.B^````:"Q"
M0`#HM````&@80D``Z*+\__^#Q"2%P'0)4%?H(OW__UE9:`1"0`#HB/S__X7`
M670-4&CX04``Z`;]__]966CH04``Z&S\__^%P%ET"U!3Z.[\__]96>M.:-1!
M0`#H4OS__X7`670$4%;KY&C,04``Z!TD``"_P$%``(U<!>A7Z`XD``!05U/_
M%71`0`"#Q!2%P'425^CX(P```\-05NB?_/__@\0,:+Q!0`!H=$)``.B-_/__
M65E?7EO)PU6+[%&-1?Q0_W4(Z/O[__]9A<!9=![_%8!`0`"+`(M-_(T,B(M1
M!(U!!(72B1%TU(O(Z_#)PZ$8L$``@_C_=25H7$)``.BN^___A<!9=`^*`(3`
M=`D\,'0%:@%8ZP(SP*,8L$``PS/`PU6+[(/L(+C@0D``5XOX4(E%X,=%Y-A"
M0`#'1>C(0D``QT7LP$)``,=%\*Q"0`#'1?2H0D``B7WXZ#`C``"%P%D/AL0`
M``"-1>!35HE%_%?H._O__XOP687V#X2#````5N@((P``A<!9='C_=0A6_Q6$
M0$``687`675SZ#(B``!0Z$0B``#_-12P0`"+..C;(@``5HO8Z-,B``#_=0@#
MV.C)(@``@\00C40#`E#H`"(``%#H$B(``%G_,/\75HOX_S44L$``_W4(:)1!
M0`!7_Q640$``5_]U^.A`^___@\0DZPO_=0A7Z#+[__]968-%_`2+1?R+.%>)
M??CH;B(``(7`60^'1O___UY;7\G#58OLN."```#H72(``(-E]`!35KNH0D``
M:+!!0`#'1=AD0T``QT7<4$%``,=%X)Q!0`")7>3'1<#X04``QT7$7$-``,=%
MR%1#0`#'1<Q,0T``QT702$-``(E=U,=%Z$!#0`#'1>PT0T``B5WPZ!'Z__^+
M\%F%]G0?5NCB(0``A<!9=!16Z&K^__]6_Q5$0$``65GI<@4``+X`!```5XEU
M^.C_(```4.@1(0``BSA95NCP(```4.@"(0``6?\P_Q=968U-^%%0_Q4`0$``
MZ!_^__^%P(E%^'4^C7WHBS=6Z'TA``"%P%EV'U;HE/G__X7`670+4/\51$!`
M`%F)1?B#QP2#??@`=-2#??@`=0G'1?@L0T``ZT2+=?B`/@!T/+\'`0``H61`
M0`"#.`%^#P^^!E=0_Q5H0$``65GK$8L-;$!```^^!HL)9HL$02/'A<!U`\8&
M7T:`/@!UR8U%P(E%_(M%_(LP5NCU(```A<!9#X:@````5N@(^?__B_!9A?8/
MA($```#H&B```%#H)B```(LXZ`T@``!0Z!,@``!965!6Z/X?``!0Z`H@``!9
M_S#_5U"#Q`R%P'5-Z.8?``!0Z.P?``!FBT`&668E`/!F/0!`=3/HS!\``%#H
MV!\``(LX66H"5NB['P``4.C''P``6?\P_Q>#Q`R%P'4+5O\51$!``%F)1?2#
M1?P$@WWT``^$3/___X-]]``/A:D```"-1=B)1?R+1?R+,%;H,2```(7`60^&
MCP```.AG'P``4.AS'P``BSCH6A\``%#H8!\``%E94%;H2Q\``%#H5Q\``%G_
M,/]74(/$#(7`=4WH,Q\``%#H.1\``&:+0`999B4`\&8]`$!U,^@9'P``4.@E
M'P``BSA9:@)6Z`@?``!0Z!0?``!9_S#_%X/$#(7`=0M6_Q5$0$``68E%](-%
M_`2#??0`#X1=_____W7XZ)$?``#_=?2+^.B''P``OB1#0``#^%;H>A\``%,#
M^.AR'P``C;P'``0``.BJ'@``4.B\'@``BQ"#Q!2)5?Q7Z)8>``!0Z*@>``!9
M_S"+1?S_$/]U^(E%_%:+-91`0`#_-1"P0`#_=?1H&$-``%#_UO]U_/\5<$!`
M`&C`0D``Z#7W__]0_Q5$0$``BWT(4/\WZ&7U__^#Q#2)10B%P'4%BP>)10CH
M3?O__X7`#X4I`@``Z"0>``!0Z#`>``"+.,<$)`"```#_=0CH#1X``%#H&1X`
M`%G_,/]7/(/$#(E%"(7`#X3S`0``Z.X=``!0Z/H=``!9BSAJ`FK_:N[_=0CH
MUQT``%#HXQT``%G_,/]7,.C&'0``4.C2'0``BSB#Q!B-A2!___]J!E#_=0CH
MJAT``%#HMAT``%G_,/]71(/$$("]('___P`/A;4```"`O2%___]##X6H````
M@+TB?___00^%FP```("](W___T,/A8X```"`O21___](#X6!````@+TE?___
M175XZ$P=``!0Z%@=``!9BSAJ`FK_:L;_=0CH-1T``%#H01T``%G_,/]7,.@D
M'0``4.@P'0``BSB#Q!B-A2!___]J*5#_=0CH"!T``%#H%!T``%G_,/]71(V%
M('___U-0_S40L$``_W7\:`A#0`#_=?S_UH/$*.DB`0``C84@____4.@V`0``
MZ,@<``!0Z-0<``!968LXC84@?___:`"```!0_W4(Z*H<``!0Z+8<``!9_S#_
M5T2#Q!"%P'XD4(V%('___U"-A2#___]0Z!X!``#H?AP``%#HBAP``(/$$.NS
MZ&X<``!0Z'H<``"+.%G_=0CH71P``%#H:1P``%G_,/]7$(V%(/___U"-1:Q0
MZ+L3``"-18"#Q!`S_XE%"`^V1#VL4&@`0T``_W4(_]:#10@"@\0,1X/_%'SC
MC46`4X!EJ`!0_S40L$``_W7\:`A#0`#K06B\04``:%Q"0`#H7?7__UE94^CI
M&P``4.@!'```BSCHW!L``%#H]!L``/\P_U=H@\0,4/\U$+!``/]U_&CP0D``
M_W7\_]:#Q!C_=?QHL$%``.@6]?___W7\Z/'X__^+1?R#Q`Q?7EO)PXM$)`0S
MR<<``2-%9\=`!(FKS>_'0`C^W+J8QT`,=E0R$,=`$/#ATL.)2!2)2!B)2%S#
M58OL4XM=$%:+=0A7BTX4C039.\%S`_]&&(E&%(O#P>@=`488BT9<A<!T-&I`
M7ROX._M^`HO[BT9<5_]U#(U$!AQ0Z!0<```!?0P!?ER#Q`PKWX-^7$!U2U;H
M2@```%F#^T!\+(O[P>\&B\?WV,'@!@/8:D"-1AS_=0Q0Z-L;``"#10Q`5N@>
M````@\003W7B4XU&'/]U#%#HOAL``(/$#(E>7%]>6UW#58OL@>Q4`0``BT4(
M4U97C5`<C;6L_O__QT4($````(L*@\($B_F+V8'G``#_`,'K$`O[B]F!XP#_
M``#!X1`+V<'O",'C"`O[B3Z#Q@3_30AUS6I`C96T_O__7HM*+#-*&#-*^#,*
M@\($B_D#R<'O'POY3HEZ-'7CBW@$BU`(BW`,BPB+WR/7]],CWHOQ"]J+T<'J
M&\'F!0O6BW`0`_,#UHNUK/[__XV4,IEY@EJ+]\'F'L'O`@OWB_GWUR-X"(EU
M["/QB]H+_HORP>L;P>8%"]Z+M;#^__\#]P/>BW`,C;PSF7F"6HOQB]F)??C!
MYA[!ZP(+\XO:]],C7>R)=?PC\@O>B[6T_O__B5T(B]_!ZQO!YP4+WXM]"`/W
MB_K!YQ[!Z@(#WHMP"`OZBU7XC;0SF7F"6HM=^/?2(U7\(]^)??2+_@O3B][!
M[QO!XP4+^XN=N/[__P/:`_N+5>R-G!>9>8):BWWXB]>)70C!XA[![P(+UXO^
M]]<C??2)5?@CU@OZB]/!ZAO!XP4+TXN=O/[__P/?BWW\`].-E#J9>8):B_[!
MYQ[![@(+_HMU"/?6(W7XB7WP(WT(B]K!XP4+]XOZP>\;"_N+G<#^__\#WHMU
M]`/[C9PWF7F"6HM]"(OWB5W\P>8>P>\""_>+^O?7(WWPB74((_(+_HOSP>X;
MP>,%"_.+G<3^__\#WXM]^`/SC;0^F7F"6HOZP><>P>H""_J+5?SWTB-5"(E]
M["-]_(O>P>,%"]>+_L'O&PO[BYW(_O__`]J+5?`#^XV<%YEY@EJ+??R+UXE=
M^,'B'L'O`@O7B_[WUR-][(E5_"/6"_J+T\'J&\'C!0O3BYW,_O__`]^+?0@#
MTXM=^(V4.IEY@EJ+_L'G'L'N`@O^BW7X]]8C=?PCWXE]](OZ"_.+VL'O&\'C
M!0O[BYW0_O__`]Z+=>P#^XV<-YEY@EJ+??B+]XE=",'F'L'O`@OWB_KWUR-]
M](EU^"/R"_Z+\\'N&\'C!0OSBYW4_O__`]^+??P#\XVT/IEY@EJ+^L'G'L'J
M`@OZBU4(]](C5?B)??`C?0B+WL'C!0O7B_[![QL+^XN=V/[__P/:BU7T`_N-
MG!>9>8):BWT(B]>)7?S!XA[![P(+UXO^]]<C??")50@CU@OZB]/!ZAO!XP4+
MTXN=W/[__P/?BWWX`].-E#J9>8):B_[!YQ[![@(+_HMU_/?6(W4(B7WL(WW\
MB]K!XP4+]XOZP>\;"_N+G>#^__\#WHMU\`/[C9PWF7F"6HM]_(OWB5WXP>8>
MP>\""_>+^O?7(WWLB77\(_(+_HOSP>X;P>,%"_.+G>3^__\#WXM]"`/SBUWX
MC;0^F7F"6HOZP><>P>H""_J+5?CWTB-5_(E]]"/?B_X+TXO>P>\;P>,%"_N+
MG>C^__\#VHM5[`/[C9P7F7F"6HM]^(O7B5T(P>(>P>\""]>+_O?7(WWTB57X
M(]8+^HO3P>H;P>,%"].+G>S^__\#WXM]_`/3C90ZF7F"6HO^P><>P>X""_Z+
M=0CWUB-U^(E]\"-]"(O:P>,%"_>+^L'O&PO[BYWP_O__`]Z+=?0#^XV<-YEY
M@EJ+?0B+]XE=_,'F'L'O`@OWB_KWUR-]\(EU""/R"_Z+\\'N&\'C!0OSBYWT
M_O__`]^+??@#\XVT/IEY@EJ+^L'G'L'J`@OZBU7\]](C50B)?>PC??P+UXO^
MP>\;B][!XP4+^XN=^/[__P/:BU7P`_N-G!>9>8):BWW\B]>)7?C!XA[![P(+
MUXO[P>\;P>,%"_N+7>R)5?PSVHN5_/[__S/>`]>+_@/:BU4(P><>P>X""_Z-
ME!.AZ]ENB7WTB_*+^HN=`/___\'N&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XV<
M-Z'KV6Z+??B+]XE=",'F'L'O`@OWB_O![QO!XP6)=?@+^XN=!/___S/R,W7T
M`]^+??P#\XVT/J'KV6Z+^L'G'L'J`@OZB]:+WHE]\,'J&\'C!0O3BUWX,]^+
MO0C___\S70@#^HM5]`/?C9P3H>O9;HM]"(E=_(O7P>(>P>\""]>+^\'O&\'C
M!0O[BUWPB54(,]J+E0S___\SW@/7B_X#VHM5^,'G'L'N`HV4$Z'KV6X+_HOR
MB]K![AO!XP4+\XM="(E][#/?B[T0____,UW\`_Z+=?`#WXM]_(V<,Z'KV6Z+
M]\'F'L'O`@OWB_N)7?B)=?S![QO!XP4+^XM=[#/>B[44____,]H#]XOZ`]Z+
M=0C!YQ[!Z@(+^HVT,Z'KV6Z)??2+UHO^BYT8____P>H;P><%"]>+??@S??P#
MVHM5[#-]]`/[C9P7H>O9;HM]^(O7B5T(P>(>P>\""]>)5?B+^S/6,U7TP>\;
MP>,%"_N+G1S___\#WXM]_`/3C90ZH>O9;HO^P><>P>X""_Z+\HO:B7WPP>X;
MP>,%"_.+7?@SWXN](/___S-="`/^BW7T`]^+?0B-G#.AZ]ENB_?!YA[![P(+
M]XO[B5W\B74(P>\;P>,%"_N+7?`SWHNU)/___S/:`_<#WHMU^(OZP><>P>H"
MC;0SH>O9;@OZB]:+WL'J&\'C!0O3BUT(B7WL,]^+O2C___\S7?P#^HM5\`/?
MBWW\C9P3H>O9;HO7P>(>P>\""]>+^XE=^(E5_,'O&\'C!0O[BUWL,]J+E2S_
M__\SW@/7B_X#VHM5",'G'L'N`@O^C903H>O9;HE]](ORB_J+G3#____![AO!
MYP4+]XM]^#-]_`/>BW7L,WWT`_N-G#>AZ]ENBWWXB_>)70C!YA[![P(+]XO[
MP>\;P>,%B77X"_N+G33___\S\C-U]`/?BWW\`_.-M#ZAZ]ENB_K!YQ[!Z@(+
M^HO6B]Z)??#!ZAO!XP4+TXM=^#/?B[TX____,UT(`_J+5?0#WXM]"(V<$Z'K
MV6Z+U\'B'L'O`@O7B_N)7?R)50C![QO!XP4+^XM=\#/:BY4\____,]X#UP/:
MBU7XC;P3H>O9;HO6P>(>P>X""]:+]XO?P>X;P>,%"_.+70B)5>PSVHN50/__
M_S-=_`/6BW7\`]J+5?"-G!.AZ]ENB];!XA[![@(+UHOSB5WXB57\P>X;P>,%
M"_.+7>PSVHN51/___S/?`]:+]P/:BU4(P>8>P>\""_>-E!.AZ]ENB77TB_*+
M^HN=2/___\'N&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XVT-Z'KV6Z+??B)=0B+
M]\'F'L'O`@OWB_H+??2+70B)=?@C_HOR(W7TP>,%"_Z+=0C![AL+\XN=3/__
M_P/?BWW\`_.-M#[<O!N/B_K!YQ[!Z@(+^HO7B7WP"U4((U7X(WT(B]X+UXO^
MP>\;P>,%"_N+G5#___\#VHM5]`/[C9P7W+P;CXM]"(O7B5W\P>(>P>\""]>+
M^HE5"`O^(]8C??`+^HO3P>H;P>,%"].+G53___\#WXM]^`/3C90ZW+P;CXO^
MP><>P>X""_Z+VHOWB7WL"W7\(WW\P>,%(W4("_>+^L'O&PO[BYU8____`]Z+
M=?`#^XV<-]R\&X^+??R+]XE=^,'F'L'O`@OWB_Z)=?P+^B/R(WWL"_Z+\\'N
M&\'C!0OSBYU<____`]^+?0@#\XVT/MR\&X^+^L'G'L'J`@OZBU7\B7WTBUW\
M"]<C5?@CWXO^"].+WL'O&\'C!0O[BYU@____`]J+5>P#^XV4%]R\&X^+??B)
M50B+U\'B'L'O`@O7B_X+??2+70B)5?@C^HO6(U7TP>,%"_J+50C!ZAL+TXN=
M9/___P/?BWW\`].-E#K<O!N/B_[!YQ[![@(+_HO:B_>)??`+=0@C?0C!XP4C
M=?@+]XOZP>\;"_N+G6C___\#WHMU]`/[C9PWW+P;CXM]"(OWB5W\P>8>P>\"
M"_>+_HEU"`OZ(_(C??`+_HOSP>X;P>,%"_.+G6S___\#WXM]^`/SC;0^W+P;
MCXOZP><>P>H""_J+WHO7B7WL"U7\(WW\P>,%(U4("]>+_L'O&PO[BYUP____
M`]J+5?`#^XV<%]R\&X^+??R+UXE=^,'B'L'O`@O7B_J)5?P+_B/6(WWL"_J+
MT\'J&\'C!0O3BYUT____`]^+?0@#TXM=_(V4.MR\&X^+_L'G'L'N`@O^BW7\
M"_<CWR-U^(E]](OZ"_.+VL'O&\'C!0O[BYUX____`]Z+=>P#^XVT-]R\&X^+
M??B)=0B+]\'F'L'O`@OWB_H+??2+70B)=?@C_HOR(W7TP>,%"_Z+=0C![AL+
M\XN=?/___P/?`_.+??R-M#[<O!N/B_K!YQ[!Z@(+^HO>B]>)??`+50@C?0C!
MXP4C5?@+UXO^P>\;"_N+78`#VHM5]`/[C9P7W+P;CXM]"(O7B5W\P>(>P>\"
M"]>+^HE5"`O^(]8C??`+^HO3P>H;P>,%"].+780#WXM]^`/3C90ZW+P;CXO^
MP><>P>X""_Z+VHOWB7WL"W7\(WW\P>,%(W4("_>+^L'O&PO[BUV(`]Z+=?`#
M^XV<-]R\&X^+??R+]XE=^,'F'L'O`@OWB_Z)=?P+^B/R(WWL"_Z+\\'N&\'C
M!0OSBUV,`]^+?0@#\XM=_(VT/MR\&X^+^L'G'L'J`@OZBU7\"]<CWR-5^(E]
M](O^"].+WL'O&\'C!0O[BUV0`]J+5>P#^XV4%]R\&X^+??B)50B+U\'B'L'O
M`@O7B_X+??2+70B)5?@C^HO6(U7TP>,%"_J+50C!ZAL+TXM=E`/?BWW\`].-
ME#K<O!N/B_[!YQ[![@(+_HO:B_>)??`+=0@C?0C!XP4C=?@+]XOZP>\;"_N+
M79@#WHMU]`/[C9PWW+P;CXM]"(OWB5W\P>8>P>\""_>+^\'O&\'C!0O[BUWP
M,]Z)=0@SVHMUG`/WB_H#WHMU^,'G'L'J`HVT,];!8LH+^HO6B][!ZAO!XP4+
MTXM="#/?B7WLBWV@,UW\`_J+5?`#WXM]_(V<$];!8LJ+U\'B'L'O`@O7B_N)
M7?B)5?S![QO!XP4+^XM=[#/:BU6D,]X#UXO^`]J+50C!YQ[![@(+_HV4$];!
M8LJ)??2+\HOZBUVHP>X;P><%"_>+??@S??P#WHMU[#-]]`/[C9PWUL%BRHM]
M^(OWB5T(P>8>P>\""_>+^\'O&\'C!8EU^`O[BUVL,_(S=?0#WXM]_`/SC;0^
MUL%BRHOZP><>P>H""_J+UHO>B7WPP>H;P>,%"].+7?@SWXM]L#-="`/ZBU7T
M`]^+?0B-G!/6P6+*B]?!XA[![P(+UXO[B5W\B54(P>\;P>,%"_N+7?`SVHM5
MM#/>`]<#VHM5^(O^P><>P>X"C903UL%BR@O^B_*+VL'N&\'C!0OSBUT(B7WL
M,]^+?;@S7?P#_HMU\`/?BWW\C9PSUL%BRHOWP>8>P>\""_>+^XE=^(EU_,'O
M&\'C!0O[BUWL,]Z+=;PSV@/WB_H#WHMU",'G'L'J`@OZC;0SUL%BRHE]](O6
MB_[!ZAO!YP4+UXM]^(M=P#-]_`/:BU7L,WWT`_N-G!?6P6+*BWWXB]>)70C!
MXA[![P(+UXO[P>\;P>,%B57X"_N+7<0SUC-5]`/?BWW\`].-E#K6P6+*B_[!
MYQ[![@(+_HORB]J)??#![AO!XP4+\XM=^#/?BWW(,UT(`_Z+=?0#WXM]"(V<
M,];!8LJ+]\'F'L'O`@OWB_N)7?R)=0C![QO!XP4+^XM=\#/>BW7,,]H#]P/>
MBW7XB_K!YQ[!Z@*-M#/6P6+*"_J+UHO>P>H;P>,%"].+70B)?>PSWXM]T#-=
M_`/ZBU7P`]^-G!/6P6+*BWW\B5WXB]?!XA[![P(+UXO[P>\;P>,%"_N+7>R)
M5?PSVHM5U#/>`]>+_@/:BU4(P><>P>X""_Z-E!/6P6+*B7WTB_*+^HM=V,'N
M&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XV<-];!8LJ+??B+]XE=",'F'L'O`@OW
MB_O![QO!XP6)=?@+^XM=W#/R,W7T`]^+??P#\XVT/M;!8LJ+^L'G'L'J`@OZ
MB]:+WHE]\,'J&\'C!0O3BUWX,]^+?>`S70@#^HM5]`/?BWT(C9P3UL%BRHO7
MP>(>P>\""]>)7?R)50B+^\'O&\'C!0O[BUWP,]J+5>0SW@/7`]J+5?B+_L'G
M'L'N`HV4$];!8LJ+70@+_HORB57T,]_![AO!X@4+\HM5_#/:`\X#V8M-\`-=
MZ(MU](V,"];!8LJ)"(M(!`/.B4@$B\K!X1[!Z@(+RHM5"`-("(E("(M(#`//
M7XE(#(M($`/*7HE($%O)PU6+[%-6BW4,BT88BUX4B44,B\/!Z`.#X#_&1#`<
M@$"#^#A^*FI`62O(C40P'%%J`%#H3`D``%;HC>W__VHXC48<:@!0Z#D)``"#
MQ!SK%6HX62O(C40P'%%J`%#H(@D``(/$#(M%#%:+R(A&5\'I&(A.5(O(P>D0
MB$Y5B\B+P_]U",'H&(A&6(O#P>@0B$99B\/!Z0C!Z`B(3E:(1EJ(7EOH!@``
M`%E97EM=PU:+="0,5N@3[?__BT0D#%F+#L'I&(@(BP[!Z1"(2`&+#L'I"(A(
M`HH.B$@#BU8$C4X$P>H8B%`$BQ'!ZA"(4`6+$<'J"(A0!HH)B$@'BU8(C4X(
MP>H8B%`(BQ'!ZA"(4`F+$<'J"(A0"HH)B$@+BU8,C4X,P>H8B%`,BQ'!ZA"(
M4`V+$<'J"(A0#HH)B$@/BU80C4X07L'J&(A0$(L1P>H0B%`1BQ'!Z@B(4!**
M"8A($\.!["0!``!3BYPD+`$``%97A=L/A#$"``!3Z,<'``"%P%D/A"("``!3
MZ+@'``"+\('&`@$``.CO!@``4.@!!P``BSA965;HWP8``%#H\08``%G_,/\7
MBSV40$``B_!3:(!#0`!6_]>-1"0L4%;_%4A`0`"#Q!R#^/^)1"04#X3'`0``
M58LMA$!``(U$)#!H4$%``%#_U5F%P%F-1"0P4'4.4VAX0T``5O_7@\00ZPMH
M=$-``%;_UX/$#+MP0T``4U;_U8OX687_670>4U?H#@<``%F%P%ET+&AL0T``
M5^C]!@``687`670;]D0D'!!T7(.\)#P!````=%)J`5;H__[__UE9C40D'%#_
M="0<_Q5,0$``687`60^%$P$``(U$)#!H4$%``%#_U5F%P%F-1"0P4'5;_[0D
M/`$``&AX0T``5O\5E$!``(/$$.M2C40D,%#_%0A`0`"#9"00`(L]4$!``(E$
M)!16_]>%P%ETEHM$)!#_1"00@_@*?8F#?"04`'0*_W0D%/\5#$!``%;KV&AT
M0T``5O\5E$!``(/$#%-6_]6+^%F%_UET)E-7Z"\&``!9A<!9#X1)____:&Q#
M0`!7Z!H&``!9A<!9#X0T____]D0D'!!T#H.\)#P!````#X45____C40D,%#_
M%0A`0`"#9"00`(L]4$!``(E$)!16_]>%P%D/A/G^__^+1"00_T0D$(/X"@^-
MZ/[__X-\)!0`=`K_="04_Q4,0$``5NO0_W0D&/\5H$!``/^T)#P!``#_%5A`
M0`!965U?7EN!Q"0!``##4U:+="0,5U;H_M___XOX5^C,W___68O86>C4X?__
MA<!T-(7V=#!6Z&8%``"%P%ET)6@D0T``4_\5A$!``%D[PUEU$VH!5NAB_?__
M:@!7Z%K]__^#Q!!?7EO#48-D)```4U97Z&X$``!0Z,($``!J`5N(&,<$)'1"
M0`#H-=W__X7`670+@#@Q=0:`>`$`=`7H_=___VH+4VCL0T``Z#4$``!0Z(,$
M``"#Q!"%P`^$GP```(M`##D=/+1``%6+\XMX&'YBO0`$``"-1O]J`%!7Z`($
M``!0Z$H$``"#Q!"%P'1$BP"+2`@CS3O-=06+0`SK$VH":@!0Z-L#``!0Z!T$
M``"#Q!!0H4"T0`#_-+#H>@0``%F%P%EU#?]$)!!&.S4\M$``?*.A/+1``%V-
M2/\Y3"0,=1T[PXOS?A=7Z)8#``!0Z-(#``!&63LU/+1``%E\Z6H%4VCH0T``
MZ'@#``!0Z,8#``"+\(/$$(7V=#&+1@QHW$-``/\PZ%H#``!0Z)`#``"+1@R#
MQ`R+`/9`"D!T#E#H0`,``%#H<`,``%E9:@53:-A#0`#H*P,``%#H>0,``(OP
M@\00A?9T;FB@04``Z/#;__^%P%ET`U#K2>A1X/__B_B%_W0WBT8,5_\PZ/0"
M``!0Z"H#``#HZ0(``%#H^P(``(LP@\005^C8`@``4.CJ`@``6?\P_U8(65GK
M&J%`M$``_S"+1@S_,.BW`@``4.CM`@``@\0,Z*D"``!0Z/T"``"`(`#HFP(`
M`%#HQ0(``(,@`&BP04``Z&;;__^#Q`RC.+!``(7`=1'_-4"T0`#HS>#__UFC
M.+!``.AF`@``4.B*`@``BS#'!"3M`0``_S4XL$``Z$P"``!0Z'`"``!9_S#_
M%H/$#(7`7UY;="6#^!%T((/X_W0;4*%`M$``_S4XL$``_S!HB$-``.@Y`@``
M@\006<-5B^Q148U%$%90C44,4(U%"%#HFP(``&H`Z(X"``"#Q!"`.`!U3.A[
M`@``A<"C-+!``'4CZ-<!``!0Z.\!``"+,%EJ`>C'`0``4.C?`0``6?\P_U8(
M65G_-32P0`#H/@(``.BI`0``4.@M`@``@"``65GHF0$``%#H%P(``(`(`NB+
M`0``4.@)`@``@`@!BT4(@V7\`(/`!8E%^%G?;?A9W!T`1$``W^">=@S_-<1`
M0`#H?@$``%F+10B-!(44````4.C'`0``6:-`M$``BTT,:@&+"8D(H4"T0`#'
M0`3X0T``H4"T0`#'0`@@1$``H4"T0`#'!3RT0``#````QT`,]$-``/\%/+1`
M`%@Y10A^'HL-/+1``(M5#(LU0+1```/(BQ2"0(E4COP[10A\XJ$\M$``BTT(
M`\&+#4"T0`!J`(-D@?P`BT4(BPT\M$``_S5`M$``C40!_U!HX#A``/\U-+!`
M`.@?`0``B_"#Q!2%]G4._S4TL$``Z`4!``!9B_#_-32P0`#H\0```,<$)&A"
M0`#H5]G__X7`674DH3BP0`"%P'44:+!!0`#H/]G__X7`6:,XL$``=`=0Z'O[
M__]9_S4TL$``Z*L```!9Z)\```"+QE[)P^@U````4.@5U___6;BH0D``:@!0
M4&B>-$``:`A$0`#H%@```%#HN````(/$&,/_)21!0`#_)2!!0`#_)1Q!0`#_
M)1A!0`#_)11!0`#_)1!!0`#_)0Q!0`#_)0A!0`#_)01!0`#_)0!!0`#_)?Q`
M0`#_)?A`0`#_)?1`0`#_)?!`0`#_)>Q`0`#_)>A`0`#_)>1`0`#_)>!`0`#_
M)=Q`0`#_)=A`0`#_)=1`0`#_)=!`0`#_)<Q`0`#_)<A`0`#_)<!`0`#_);Q`
M0`#_);A`0`#_);1`0`#_);!`0`#_):Q`0`#_):A`0`#,S,S,S,S,S/\ED$!`
M`/\EB$!``,S,S,Q1/0`0``"-3"0(<A2!Z0`0```M`!```(4!/0`0``!S["O(
MB\2%`8OABPB+0`10P\S_)6!`0`#_)5Q`0`#,S,S,58OL:O]HX)U``&A0.T``
M9*$`````4&2))0````"#["!35E>)9>B#9?P`:@'_%51`0`!9@PU8M$``_X,-
M7+1``/__%1A`0`"+#52T0`")"/\5'$!``(L-4+1``(D(H2!`0`"+`*-@M$``
MZ,````"#/3"P0```=0QH9A9``/\5)$!``%GHE````&@,L$``:`BP0`#H?P``
M`*%,M$``B478C4784/\U2+1``(U%X%"-1=10C47D4/\5+$!``&@$L$``:`"P
M0`#H3````/\5,$!``(M-X(D(_W7@_W74_W7DZ`?\__^#Q#")1=Q0_Q4T0$``
MBT7LBPB+"8E-T%!1Z`\```!96<.+9>C_==#_%3Q`0`#_)3A`0`#_)2A`0`!H
M```#`&@```$`Z`L```!96</#S/\EF$!``/\EG$!`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````!"B````````[J$``."A``#*H0```````*ZC``">HP``CJ,``'JC``!N
MHP``7J,``$ZC``!&HP``.*,``#"C```8HP``#J,```"C``#TH@``ZJ(``+RC
M``#2H@``R*(``+ZB``"NH@``HJ(``)BB``".H@``A*(``'JB``!PH@``8*(`
M`%:B``!,H@``0J(``#BB```NH@``SJ,``.*C``#<H@```````*JA``"8H0``
M@J$``'2A``!BH0``0J$``"JA```8H0```J$``/2@``#HH```V*```,R@``"\
MH```J*```):@``"&H```<J```&*@``!2H```1*```#"@```@H```"*```/:?
M``#FGP``UI\``,*?``"PGP``G)\``(Z?``!\GP``````````````````CJMK
M1P`````"````2@``````````X```.P```%P```!7:6XS,D-/4D4Z.F)O;W1S
M=')A<`````!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`<&5R;'AS:2YC
M````)7,E<R5S```N````4$%27U!23T=.04U%`````%!!4E]414U0`````#$`
M``!005)?0TQ%04X]``!#3$5!3@```%!!4E]'3$]"04Q?0TQ%04X`````4$%2
M7T=,3T)!3%]414U0`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$U01$E2````
M4$%27T=,3T)!3%]$14)51P````!005)?05)'5E\P``!005)?05)'0P````!0
M05)?0T%#2$4```!005)?1$5"54<```!005)?0TQ%04X```!005)?4U!!5TY%
M1`!005)?24Y)5$E!3$E:140`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("```````````$193$1?3$E"4D%265]0051(````4$%42`````!,24)2
M05)97U!!5$@`````3$E"4$%42`!,1%],24)205)97U!!5$@`)7,E<W1E;7`M
M)74E<P```"4P,G@`````)7,E<V-A8VAE+25S)7,``"5S)7,E<R5S`````'!A
M<BT`````4UE35$5-``!54T523D%-10````!54T52`````%1-4`!414U0````
M`%1%35!$25(`5$U01$E2``!#.EQ414U0`%PN+@!<+@``)7,``"5S7"5S````
M)7-<*BXJ```E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@```#``
M``!P97)L+F5X90`````8````05)'5@`````M+0``+64``````````(#____/
M04EN=&5R;F%L<SHZ4$%2.CI"3T]4`````",A+W5S<B]B:6XO<&5R;`H*979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@
M7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY
M(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC
M;&EN92`Q-3D*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I
M;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q
M=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG
M(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD
M9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T
M96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(')M9&ER("1T;W!D:7([
M"@H@("`@:68@*"UD("1P87)?=&5M<"D@>PH@("`@("`@(",@4V]M971H:6YG
M('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y
M+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O
M<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@
M;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N
M;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N
M9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P
M<F]C97-S+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@
M("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@
M($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@
M("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+
M(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@(R!"96-A=7-E('1H92!P87)?
M=&5M<"!D:7)E8W1O<GD@:7,@9V]I;F<@=&\@8F4@9&5L971E9"!I;B!A"B`@
M("`@("`@(R!B86-K9W)O=6YD('!R;V-E<W,L('1H92!P87)E;G0@<')O8V5S
M<R!I9"!M87D@8F4@<F5U<V5D(&)E9F]R92!T:&4*("`@("`@("`C(&)A8VMG
M<F]U;F0@<')O8V5S<R!C;VUP;&5T97,N("!4;R!E;G-U<F4@=&AA="!T:&4@
M=&5M<&]R87)Y"B`@("`@("`@(R!D:7)E8W1O<GD@9&]E<R!N;W0@9V5T(')E
M=7-E9"!W:&EL92!I="!I<R!B96EN9R!D96QE=&5D+"!T<GD@=&\*("`@("`@
M("`C(')E;F%M92!I="!T;R!A(&YA;64@=&AA="!I<R!R96QA=&5D('1O('1H
M92!T96UP;W)A<GD@<V-R:7!T(&9I;&4N"@H@("`@("`@(&UY("1T;7!N86UE
M(#T@*$9I;&4Z.E-P96,M/G-P;&ET<&%T:"@D=&UP+3YF:6QE;F%M92DI6S)=
M.R`C(&9I;&5N86UE"B`@("`@("`@)'1M<&YA;64@/7X@<R]<+EM>+ETJ)"\N
M9&ER+SL*("`@("`@("!M>2`D;F5W1&ER(#T@1FEL93HZ4W!E8RT^8V%T<&%T
M:"@*("`@("`@("`@("`@*$9I;&4Z.E-P96,M/G-P;&ET<&%T:"@D<&%R7W1E
M;7`I*5LP+BXQ72P@)'1M<&YA;64I.PH@("`@("`@(&EF("AR96YA;64@)'!A
M<E]T96UP+"`D;F5W1&ER*2!["B`@("`@("`@("`@(&]U=',H(E)E;F%M960@
M)'!A<E]T96UP('1O("1N97=$:7(B*3L*("`@("`@("`@("`@)'!A<E]T96UP
M(#T@)&YE=T1I<CL*("`@("`@("!]"@H@("`@("`@(&EF("@D7D\@/7X@;2]W
M:6XS,B]I*2!["B`@("`@("`@("`@('!R:6YT("1T;7`@(@HZ;&]O<`IR;61I
M<B`O<2`O<R!<(B1P87)?=&5M<%PB"FEF(&5X:7-T(%PB)'!A<E]T96UP7"(@
M9V]T;R!L;V]P"G)M9&ER(%PB)'1O<&1I<EPB"G)M(%PB(B`N("1T;7`M/F9I
M;&5N86UE("X@(EPB"B(["B`@("`@("`@("`@(&-L;W-E("1T;7`["B`@("`@
M("`@("`@(&UY("1P<F]C.PH@("`@("`@("`@("!7:6XS,CHZ4')O8V5S<SHZ
M0W)E871E*`H@("`@("`@("`@("`@("`@)'!R;V,L("1%3E9[0T]-4U!%0WTL
M"B`@("`@("`@("`@("`@("`B)$5.5GM#3TU34$5#?2`O8R!<(B(@+B`D=&UP
M+3YF:6QE;F%M92`N(")<(B`^;G5L(#(^;G5L("(L"B`@("`@("`@("`@("`@
M("`Q+"!.3U)-04Q?4%))3U))5%E?0TQ!4U,L("(N(@H@("`@("`@("`@("`I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R:6YT("1T;7`@(B,A
M+V)I;B]S:`IW:&EL92!;("UD("<D<&%R7W1E;7`G(%T[(&1O"B`@(')M("UR
M9B`G)'!A<E]T96UP)PID;VYE"G)M9&ER("<D=&]P9&ER)PIR;2`G(B`N("1T
M;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*("`@("`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I
M;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@("`@(&-L
M;W-E("1T;7`["B`@("`@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!]
M"B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`I*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@
M*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]
M("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@
M+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'
M5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@
M9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I
M9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?
M97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO
M(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H
M*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@
M86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T
M7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@
M/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O
M9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA
M;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@
M("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@
M("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K
M(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K
M(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&
M2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*
M("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE
M;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@
M("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A
M8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^
M("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U
M="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@
M("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U
M="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@
M("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U
M-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@
M("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@
M)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M
M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@
M*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL
M92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0
M?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F
M:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D
M9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I
M.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L
M;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2
M.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@
M("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C
M<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@
M("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0[
M"B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@
M("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I
M;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@
M>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK
M97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL
M97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?
M.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O
M<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!
M3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@
M(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@
M("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H
M("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P
M*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@
M96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I
M;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H
M)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@
M("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@
M("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@
M3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L
M:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO
M861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R
M<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G
M<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@
M<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O
M=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP
M;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R
M(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE
M;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N
M<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?
M1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*
M"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U
M=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A
M<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A
M;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF
M>5]P87(*("`@("D["B`@("!W:&EL92`H0$%21U8I('L*("`@("`@("`D05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*
M("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@('5N<VAI9G0@
M0$E.0RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G32<I
M('L*("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("!]"B`@("`@
M("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("!U;G-H:69T($!P
M87)?87)G<RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M3R<I('L*("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@('T*("`@("`@
M("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("1B=6YD;&4@/2`G
M<VET92<["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*
M("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@('T*("`@("`@
M("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("1Q=6EE="`](#$[
M"B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@
M("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN
M;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q
M(&5Q("=4)RD@>PH@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@
M("`@('T*"B`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("!I9B`H;7D@
M)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@9&5L971E("1%
M3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@
M("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`F>R)005(Z
M.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@
M97AI=#L*("`@("`@("!]"B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD
M96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD
M;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@
M("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H
M:79E.CI::7`["B`@("!]"@H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD[
M"B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@
M("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD
M("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B
M;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@
M("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]
M"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@
M("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M
M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@
M*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P
M96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@
M7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2
M+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D
M92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@
M=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A
M=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D
M9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P
M;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E
M<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]
M"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@
M("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L
M(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D
M;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@
M("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@
M("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M
M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E
M="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E
M<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U
M;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@
M<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@(')E
M<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@
M("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!]
M(&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@
M>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@
M("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@
M("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI
M.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@:68@*"1#;VYF:6=[7V1E;&EM
M?2!E<2`G7%PG*2![('-[7%Q]>R]]9R!F;W(@0&EN8R!]"@H@("`@("`@(&UY
M("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`D9FEL97-[)#%]*RL@
M9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S
M("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG
M>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E
M86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M
M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@
M)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#
M8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E
M<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@
M(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@
M9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@
M("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@
M("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE
M+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@
M("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@
M("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE
M(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@
M("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@
M/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@
M("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@
M=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@("`@("`@("1C
M;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R
M>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")8
M4TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S
M*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R
M:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H
M<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@
M("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT
M*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E
M(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N
M86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A
M8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@
M("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@
M("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T
M.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I
M;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V
M97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`[
M"B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE
M*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O
M=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@
M8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@
M("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F
M:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C
M:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]
M"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM[
M"GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?
M9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@
M86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E
M(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@
M("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?
M(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&
M:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@
M;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R
M(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[
M4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I
M;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES
M('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA
M;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_
M<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R
M<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@
M("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R
M86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PH@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D["B`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B
M)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("!]"B`@
M("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP
M;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8[
M"E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE
M(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]
M"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*
M("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*
M("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@
M)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I
M<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)
M3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@
M("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@
M("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@
M<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#
M87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@
M<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U
M:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R
M97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U
M:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP
M.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@
M("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L
M('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(Z
M.E!R;V-E<W,@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T[
M"GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M
M>6QD<B]M:W1M<&1I<BYC"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("@D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@
M?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@
M("`@;F5X="!U;FQE<W,@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T
M:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@
M("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V
M86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*
M"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*
M("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@
M("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@
M("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@
M("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER
M(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@
M("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!
M4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=
M*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S
M>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X
M+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@
M("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@
M("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@
M(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD
M(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@
M>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@
M("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N
M(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X
M+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*
M"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@
M("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@
M*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*
M("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF
M("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE
M(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL
M96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F
M+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P
M96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E
M*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@IS=6(@7W-E
M=%]P<F]G;F%M92!["B`@("!I9B`H)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N
M86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H
M)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@
M("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@
M("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF
M("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@
M)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@
M("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[
M7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@
M("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*
M"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M
M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D
M("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@
M("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]
M?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG
M>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@
M96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@
M('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#
M2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@
M)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[
M4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*
M("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@
M,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.
M?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]
M"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H
M)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*
M("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B
M(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET
M96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@
M("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I
M;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X[
M"@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG
M="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@
M;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z
M.E]?15)23U(["@HQ.PH*(VQI;F4@,3`P.0H*7U]%3D1?7PH`````<&%R+G!L
M````````_____Q`[0``D.T``^)X`````````````OJ$``*A```!8G@``````
M```````"H@``"$```%">`````````````""B````0```:)X`````````````
M)*,``!A``````````````````````````````!"B````````[J$``."A``#*
MH0```````*ZC``">HP``CJ,``'JC``!NHP``7J,``$ZC``!&HP``.*,``#"C
M```8HP``#J,```"C``#TH@``ZJ(``+RC``#2H@``R*(``+ZB``"NH@``HJ(`
M`)BB``".H@``A*(``'JB``!PH@``8*(``%:B``!,H@``0J(``#BB```NH@``
MSJ,``.*C``#<H@```````*JA``"8H0``@J$``'2A``!BH0``0J$``"JA```8
MH0```J$``/2@``#HH```V*```,R@``"\H```J*```):@``"&H```<J```&*@
M``!2H```1*```#"@```@H```"*```/:?``#FGP``UI\``,*?``"PGP``G)\`
M`(Z?``!\GP```````*8$8F]O=%]7:6XS,D-/4D4``$<#4&5R;%]N97=84P``
M5`)097)L7V=E=%]C;VYT97AT``"E!&)O;W1?1'EN84QO861E<@";`5!E<FQ?
M27-T871B=69?<'1R`,$`4&5R;%])3$E/7W!T<@#$`%!E<FQ?24UE;5]P='(`
MR`!097)L7TE0<F]C7W!T<@``%@)097)L7V-R;V%K7VYO8V]N=&5X=```OP!0
M97)L7TE$:7)?<'1R`.0`4&5R;%])8V]M<&-V7W!T<@``]0)097)L7VUG7W-E
M=``Y!%!E<FQ?<W9?<V5T<'8```)097)L7V%V7W-H:69T`.<#4&5R;%]S=E\R
M<'9?9FQA9W,`^0%097)L7V%V7V9E=&-H`'@"4&5R;%]G=E]F971C:'!V`+`!
M4&5R;%])=&%I;G1E9%]P='(`;`1097)L7W-Y<U]T97)M`+`$<&5R;%]F<F5E
M`*\$<&5R;%]D97-T<G5C=`"S!'!E<FQ?<G5N``"R!'!E<FQ?<&%R<V4``)L#
M4&5R;%]S869E<WES;6%L;&]C```$`%!,7VUE;6]R>5]W<F%P```3`5!E<FQ?
M265X:71?9FQA9W-?<'1R``!J`5!E<FQ?27!E<FQ?9&5S=')U8W1?;&5V96Q?
M<'1R`*X$<&5R;%]C;VYS=')U8W0``*@$<&5R;%]A;&QO8P``F`!097)L7T=D
M;U]U;F1U;7!?<'1R`&@$4&5R;%]S>7-?:6YI=#,``$@#4&5R;%]N97=84U]F
M;&%G<P``<&5R;#4Q,"YD;&P`=0%'971-;V1U;&5&:6QE3F%M94$``.\`1G)E
M94QI8G)A<GD`=P%'971-;V1U;&5(86YD;&5!``!+15).14PS,BYD;&P``",!
M1V5T57-E<DYA;65!``!!1%9!4$DS,BYD;&P``+("<W!R:6YT9@"X`G-T<F-M
M<```QP)S=')T;VL``+X"<W1R;&5N``#%`G-T<G-T<@``;0!?7W!?7V5N=FER
M;VX``)@";65M;6]V90#!`G-T<FYC<'D`P`)S=')N8VUP`((!7VUK9&ER``".
M`5]P8W1Y<&4`%0%?:7-C='EP90``80!?7VUB7V-U<E]M87@``)<";65M8W!Y
M``"9`FUE;7-E=```F0%?<FUD:7(``-\`7V9I;F1C;&]S90``W0%?=6YL:6YK
M`.(`7V9I;F1N97AT`.``7V9I;F1F:7)S=```OP%?<W1R9'5P`,4!7W-T<FYI
M8VUP`$U35D-25"YD;&P``-,`7V5X:70`2`!?6&-P=$9I;'1E<@!)`F5X:70`
M`&0`7U]P7U]?:6YI=&5N=@!8`%]?9V5T;6%I;F%R9W,`#P%?:6YI='1E<FT`
M@P!?7W-E='5S97)M871H97)R``"=`%]A9&IU<W1?9F1I=@``:@!?7W!?7V-O
M;6UO9&4``&\`7U]P7U]F;6]D90``@0!?7W-E=%]A<'!?='EP90``R@!?97AC
M97!T7VAA;F1L97(S``"W`%]C;VYT<F]L9G``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````4$%``$Q!0`#_____U)U``+!9
M```````````````````!````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````#``,````H``"`#@```$@``(`0
M````8```@````````````````````@`!````>```@`(```"0``"`````````
M```````````!`&4```"H``"````````````````````!``$```#```"`````
M```````````````!``````#8```````````````````````!``````#H````
M```````````````````!``````#X```````````````````````!```````(
M`0``F,,``&@%``````````````#)``"H"`````````````"HT0``(@``````
M````````(,$``'0"````````````````````````=`(T````5@!3`%\`5@!%
M`%(`4P!)`$\`3@!?`$D`3@!&`$\``````+T$[_X```$`````````````````
M`````#\````!````!``$``$```````````````````#4`0```0!3`'0`<@!I
M`&X`9P!&`&D`;`!E`$D`;@!F`&\```"P`0```0`P`#0`,``P`#``-`!B`#``
M```8`````0!#`&\`;0!M`&4`;@!T`',````@`````0!#`&\`;0!P`&$`;@!Y
M`$X`80!M`&4``````"@````!`$8`:0!L`&4`1`!E`',`8P!R`&D`<`!T`&D`
M;P!N```````@`````0!&`&D`;`!E`%8`90!R`',`:0!O`&X``````"`````!
M`$D`;@!T`&4`<@!N`&$`;`!.`&$`;0!E````)`````$`3`!E`&<`80!L`$,`
M;P!P`'D`<@!I`&<`:`!T````*`````$`3`!E`&<`80!L`%0`<@!A`&0`90!M
M`&$`<@!K`',``````"@````!`$\`<@!I`&<`:0!N`&$`;`!&`&D`;`!E`&X`
M80!M`&4````@`````0!0`'(`:0!V`&$`=`!E`$(`=0!I`&P`9````"`````!
M`%``<@!O`&0`=0!C`'0`3@!A`&T`90``````)`````$`4`!R`&\`9`!U`&,`
M=`!6`&4`<@!S`&D`;P!N````(`````$`4P!P`&4`8P!I`&$`;`!"`'4`:0!L
M`&0```!$`````0!6`&$`<@!&`&D`;`!E`$D`;@!F`&\``````"0`!````%0`
M<@!A`&X`<P!L`&$`=`!I`&\`;@````````2P!``````H````$````"`````!
M``@````````!```````````````!`````0``!@8&``0$!``"`@(``````$)"
M0@"=G9T`;FYN`(&!@0"QL;$`____`'-S<P"?GY\`6%A8`+*RL@#]_?T`:VMK
M`/S\_`#7U]<`%A86`-K:V@"6EI8`CHZ.`$9&1@#+R\L`"PL+`*"@H`#^_OX`
MR<G)`,'!P0`#`P,`$1$1`).3DP"SL[,`[N[N`/3T]`#CX^,`Y>7E`**BH@"Z
MNKH`KZ^O``<'!P!Q<7$`M;6U`/7U]0")B8D`BHJ*`#0T-`#HZ.@`-34U`%I:
M6@"WM[<`V-C8`-#0T``='1T`#`P,`(^/CP"^OKX`;6UM``D)"0";FYL`+R\O
M`,W-S0#9V=D`&1D9`$U-30!$1$0`4%!0`#P\/`!D9&0`PL+"`#(R,@`("`@`
M#0T-``\/#P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````%!04%!04%!04%!04%!00$!`35`(P5!,4-!041%
M+@$!`0$!`0$%`3P7%P$!$P$!`0$!`0$!%0$!)A4!`0\!`0$!`0$!`1,!$0$%
M-0$F`0$!`0$!`0$B$A`Q#P4!(`$!`0$!`0$!$`H@(A45+B$N`0$!`0$?("$0
M(A`C(R4F)P$!`0$E$!`0$!`0$!`0%T4!`0%!$!`0$!`0$!`0$!`7`0$!#Q`0
M%1`0$!`0$!`0`0$!`1(0$!,?$!`0$!`0!P$!`0$@$!`0`0\0$!`0$0$!`0$!
M!R`0"@$!!1`0$#$!`0$!`0$!`0$!`0%!!0\!`0$!`0$!`0$!`0$!`0$!`0$!
M`0&``0``P`$``.`#``#P`P``\`,``/`#``#@`P``P`$``(`!``"``0``@`,`
M`(`#````!P````<``(X/``#_'P``*````"````!``````0`(````````!```
M`````````````0````$````````!`0$``@("``,#`P`$!`0`!04%``8&!@`'
M!P<`"`@(``D)"0`*"@H`"PL+``P,#``-#0T`#@X.``\/#P`0$!``$1$1`!(2
M$@`3$Q,`%!04`!45%0`6%A8`%Q<7`!@8&``9&1D`&AH:`!L;&P`<'!P`'1T=
M`!X>'@`?'Q\`("`@`"$A(0`B(B(`(R,C`"0D)``E)24`)B8F`"<G)P`H*"@`
M*2DI`"HJ*@`K*RL`+"PL`"TM+0`N+BX`+R\O`#`P,``Q,3$`,C(R`#,S,P`T
M-#0`-34U`#8V-@`W-S<`.#@X`#DY.0`Z.CH`.SL[`#P\/``]/3T`/CX^`#\_
M/P!`0$``04%!`$)"0@!#0T,`1$1$`$5%10!&1D8`1T='`$A(2`!)24D`2DI*
M`$M+2P!,3$P`34U-`$Y.3@!/3T\`4%!0`%%140!24E(`4U-3`%145`!5554`
M5E96`%=75P!86%@`65E9`%I:6@!;6UL`7%Q<`%U=70!>7EX`7U]?`&!@8`!A
M86$`8F)B`&-C8P!D9&0`965E`&9F9@!G9V<`:&AH`&EI:0!J:FH`:VMK`&QL
M;`!M;6T`;FYN`&]O;P!P<'``<7%Q`')R<@!S<W,`='1T`'5U=0!V=G8`=W=W
M`'AX>`!Y>7D`>GIZ`'M[>P!\?'P`?7U]`'Y^?@!_?W\`@("``(&!@0""@H(`
M@X.#`(2$A`"%A84`AH:&`(>'AP"(B(@`B8F)`(J*B@"+BXL`C(R,`(V-C0".
MCHX`CX^/`)"0D`"1D9$`DI*2`).3DP"4E)0`E965`):6E@"7EY<`F)B8`)F9
MF0":FIH`FYN;`)R<G`"=G9T`GIZ>`)^?GP"@H*``H:&A`**BH@"CHZ,`I*2D
M`*6EI0"FIJ8`IZ>G`*BHJ`"IJ:D`JJJJ`*NKJP"LK*P`K:VM`*ZNK@"OKZ\`
ML+"P`+&QL0"RLK(`L[.S`+2TM`"UM;4`MK:V`+>WMP"XN+@`N;FY`+JZN@"[
MN[L`O+R\`+V]O0"^OKX`O[^_`,#`P`#!P<$`PL+"`,/#PP#$Q,0`Q<7%`,;&
MQ@#'Q\<`R,C(`,G)R0#*RLH`R\O+`,S,S`#-S<T`SL[.`,_/SP#0T-``T='1
M`-+2T@#3T],`U-34`-75U0#6UM8`U]?7`-C8V`#9V=D`VMK:`-O;VP#<W-P`
MW=W=`-[>W@#?W]\`X.#@`.'AX0#BXN(`X^/C`.3DY`#EY>4`YN;F`.?GYP#H
MZ.@`Z>GI`.KJZ@#KZ^L`[.SL`.WM[0#N[NX`[^_O`/#P\`#Q\?$`\O+R`//S
M\P#T]/0`]?7U`/;V]@#W]_<`^/CX`/GY^0#Z^OH`^_O[`/S\_`#]_?T`_O[^
M`/___P`T-#0\/#P\/#P\/#P\/#P\/#P\/#P\/#PL#`0$!`0$!%RTU-34U-34
MU-34U-S4U-34U-34U-34U+0T400$!`0$9,SL]/3T_/3\]/3T_/3\]/ST_/S\
M]/3LQ#11400$!`1DQ.3L]/3T]/3T]/3T]/3T]/3T]/3T[.R\-%%1400$!&3$
MY.SL[.3L[.SDY.3D[.SD[.3L[.SLY+PT45%1400$9+SD[.RLC*S4Q)24G)2,
MC)24E)R<G.S<O#1145%1401DO-SD[.3$492L9.2D3#0L7,3,4;34Y-R\-%%1
M45%1462\W.3D[.3D481TY(QLI)QLC+QTK-3DW+PT!`0$!`0$9+S<Y.3LY.2\
M48S4U(RLS'3,W*11Q.3<O#0$!`0$!`1DO-SDY.3DY-R,?)RT?(2<;,SDO'3$
MY-RT-`0$!`0$!%R\W-SDY.3DU)RD7)2,S#R49,R\C%'<U+0T!`0$!`0$9+34
MW-S<Y-R,C*PLO+3,6L1DG&R4I-S4M#0$!`0$!`1<M-3<W.3<W'24U$RD](P\
MU'24=)Q,W,RT-`0$!`0$!&2TU-S<W.3<=%'T=(3LS&3D?&RDM&RDU+0T!`0$
M!`0$9+3,W-S,?(R$M/S,Q/STM/R\9,RLA%&\K#0$!`0$!`1<M,S4S(RDW-SL
M_/S\_/ST_.RT[*Q\E%&L-`0$!`0$!%RLS,QLG/3\_/S\_/S\_/S\_/S\Q)2,
M4:PT!`0$!`0$7*S$O'SD_/S\_/S\_/S\_/S\_/SLS*Q1K#0$!`0$!`1<K+1,
MQ/S\_.ST_/S\_/S\_/S\_/2\4<2L-`0$!`0$!%RLM$S4_/STM-S\_/S\_/S\
M_/S\S%',Q*0T!`0$!`0$7*S$I%'\_/RTG/3\_/S\_/S\_/244<S$I"P$!`0$
M!`1<I*11A.S\_,QDM.S\_/S\_/S\U&RLS+RD-`0$!`0$!%RD9'2\]/S\Q%&$
MG.3\_/S\_.2,4<S,Q*0T!`0$!`0$7*1LC.3T_/R<4<Q1E.S\_/S\O'3,S,2\
MG"P$!`0$!`1<I*QD7&2DI%&LS,1TE.3T_.11O,S,Q+R<-`0$!`0$!%RDM+R\
MC%%1Q,3,S*Q1?'R4;'R\S,3$O)PL!`0$!`0$7)R\Q,3$Q,3$Q,3$Q,1145%1
MO,3$Q,2TG#0$!`0$!`14G+3$Q,3$Q,3$Q,3$Q,3$Q,3$Q,3$O+2<+`0$!`0$
M!%2<O,3$O+R\O+R\O+R\O+R\O+R\O+R\M)PL!`0$!`0$7)RTQ+RTM+2TM+2T
MM+2TM+2TM+2TM+2LG"P$!`0$!`14A)2<G)24E)24E)24E)24E)24E)24E)2$
M)`0$!`0$!$147%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%0T!`0$!`0$````/P``
M`!\````/````!P````,````!`````````#\````_````/P```#\````_````
M/P```#\````_````/P```#\````_````/P```#\````_````/P```#\````_
M````/P```#\````_````/P```#\````_````/P```#\```$``@`0$````0`(
M`&@%```!`"`@```!``@`J`@```(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!.0C$P`````(ZK:T<!````0SI<4&5R;%9E<G-I;VYS
K7#$P,#%<8G5I;&1<4$%2+5!A8VME<BTP+CDW-UQM>6QD<EQP87(N<&1B````
